[List of All Locales and Their Short Codes](https://www.alchemysoftware.com/livedocs/ezscript/Topics/Catalyst/Language.htm)
Table bellow is sorted ascending by language code. If case of add new translation, please remove missing from comment.

| Language Name                                                  | Language Code  | short form | comment        |
| -------------------------------------------------------------- | -------------- | ---------- | -------------- |
| Afrikaans (South Africa)                                       | af-ZA          | af         |                |
| Amharic (Ethiopia)                                             | am-ET          | am         | missing        |
| Arabic (U.A.E.)                                                | ar-AE          |            | missing        |
| Arabic (Bahrain)                                               | ar-BH          |            | missing        |
| Arabic (Algeria)                                               | ar-DZ          |            | missing        |
| Arabic (Egypt)                                                 | ar-EG          |            | missing        |
| Arabic (Iraq)                                                  | ar-IQ          |            | missing        |
| Arabic (Jordan)                                                | ar-JO          |            | missing        |
| Arabic (Kuwait)                                                | ar-KW          |            | missing        |
| Arabic (Lebanon)                                               | ar-LB          |            | missing        |
| Arabic (Libya)                                                 | ar-LY          |            | missing        |
| Arabic (Morocco)                                               | ar-MA          |            | missing        |
| Mapudungun (Chile)                                             | arn-CL         |            | missing        |
| Arabic (Oman)                                                  | ar-OM          |            | missing        |
| Arabic (Qatar)                                                 | ar-QA          |            | missing        |
| Arabic (Saudi Arabia)                                          | ar-SA          | ar         |                |
| Arabic (Syria)                                                 | ar-SY          |            | missing        |
| Arabic (Tunisia)                                               | ar-TN          |            | missing        |
| Arabic (Yemen)                                                 | ar-YE          |            | missing        |
| Assamese (India)                                               | as-IN          | as         | missing        |
| Azerbaijani (Cyrillic)                                         | az-Cyrl        |            | missing        |
| Azerbaijani (Cyrillic, Azerbaijan)                             | az-Cyrl-AZ     |            | missing        |
| Azerbaijani (Latin)                                            | az-Latn        |            | missing        |
| Azerbaijani (Latin, Azerbaijan)                                | az-Latn-AZ     | az         | missing        |
| Bashkir (Russia)                                               | ba-RU          | ba         | missing        |
| Belarusian (Belarus)                                           | be-BY          | be         | missing        |
| Bulgarian (Bulgaria)                                           | bg-BG          | bg         |                |
| Bangla (Bangladesh)                                            | bn-BD          | ba         | missing        |
| Bangla (India)                                                 | bn-IN          |            | missing        |
| Tibetan (People's Republic of China)                           | bo-CN          | bo         | missing        |
| Breton (France)                                                | br-FR          | br         | missing        |
| Bosnian (Cyrillic)                                             | bs-Cyrl        |            | missing        |
| Bosnian (Cyrillic, Bosnia and Herzegovina)                     | bs-Cyrl-BA     |            | missing        |
| Bosnian (Latin)                                                | bs-Latn        | bs         | missing        |
| Bosnian (Latin, Bosnia and Herzegovina)                        | bs-Latn-BA     |            | missing        |
| Catalan (Spain)                                                | ca-ES          | ca         |                |
| Valencian (Spain)                                              | ca-ES-valencia |            | missing        |
| Cherokee                                                       | chr-Cher       | chr        | missing        |
| Cherokee (United States)                                       | chr-Cher-US    |            | missing        |
| Corsican (France)                                              | co-FR          | co         | missing        |
| Czech (Czech Republic)                                         | cs-CZ          | cs         |                |
| Welsh (United Kingdom)                                         | cy-GB          | cy         | missing        |
| Danish (Denmark)                                               | da-DK          | da         | missing        |
| German (Austria)                                               | de-AT          |            | missing        |
| German (Switzerland)                                           | de-CH          |            | missing        |
| German (Germany)                                               | de-DE          | de         |                |
| German (Liechtenstein)                                         | de-LI          |            | missing        |
| German (Luxembourg)                                            | de-LU          |            | missing        |
| Lower Sorbian (Germany)                                        | dsb-DE         | dsb        | missing        |
| Divehi (Maldives)                                              | dv-MV          |            | missing        |
| Dzongkha (Bhutan)                                              | dz-BT          |            | missing        |
| Greek (Greece)                                                 | el-GR          |            | missing        |
| English (Caribbean)                                            | en-029         |            | missing        |
| English (Australia)                                            | en-AU          |            | missing        |
| English (Belize)                                               | en-BZ          |            | missing        |
| English (Canada)                                               | en-CA          |            | missing        |
| English (United Kingdom)                                       | en-GB          |            | missing        |
| English (Hong Kong)                                            | en-HK          |            | missing        |
| English (Ireland)                                              | en-IE          |            | missing        |
| English (India)                                                | en-IN          |            | missing        |
| English (Jamaica)                                              | en-JM          |            | missing        |
| English (Malaysia)                                             | en-MY          |            | missing        |
| English (New Zealand)                                          | en-NZ          |            | missing        |
| English (Republic of the Philippines)                          | en-PH          |            | missing        |
| English (Singapore)                                            | en-SG          |            | missing        |
| English (Trinidad and Tobago)                                  | en-TT          |            | missing        |
| English (United States)                                        | en-US          | en         |                |
| English (South Africa)                                         | en-ZA          |            | missing        |
| English (Zimbabwe)                                             | en-ZW          |            | missing        |
| Spanish (Latin America)                                        | es-419         |            | missing        |
| Spanish (Argentina)                                            | es-AR          |            |                |
| Spanish (Bolivia)                                              | es-BO          |            | missing        |
| Spanish (Chile)                                                | es-CL          |            |                |
| Spanish (Colombia)                                             | es-CO          |            | missing        |
| Spanish (Costa Rica)                                           | es-CR          |            |                |
| Spanish (Cuba)                                                 | es-CU          |            | missing        |
| Spanish (Dominican Republic)                                   | es-DO          |            | missing        |
| Spanish (Ecuador)                                              | es-EC          |            | missing        |
| Spanish (Spain, International Sort)                            | es-ES          | es         |                |
| Spanish (Guatemala)                                            | es-GT          |            | missing        |
| Spanish (Honduras)                                             | es-HN          |            | missing        |
| Spanish (Mexico)                                               | es-MX          |            |                |
| Spanish (Nicaragua)                                            | es-NI          |            |                |
| Spanish (Panama)                                               | es-PA          |            | missing        |
| Spanish (Peru)                                                 | es-PE          |            | missing        |
| Spanish (Puerto Rico)                                          | es-PR          |            | missing        |
| Spanish (Paraguay)                                             | es-PY          |            | missing        |
| Spanish (España)                                               | es-SP          |            | wrong iso code |
| Spanish (El Salvador)                                          | es-SV          |            | missing        |
| Spanish (United States)                                        | es-US          |            | missing        |
| Spanish (Uruguay)                                              | es-UY          |            | missing        |
| Spanish (Bolivarian Republic of Venezuela)                     | es-VE          |            | missing        |
| Estonian (Estonia)                                             | et-EE          | et         |                |
| Basque (Spain)                                                 | eu-ES          | eu         |                |
| Persian (Iran)                                                 | fa-IR          | fa         |                |
| Fulah (Latin)                                                  | ff-Latn        | ff         | missing        |
| Fulah (Latin, Senegal)                                         | ff-Latn-SN     |            | missing        |
| Finnish (Finland)                                              | fi-FI          | fi         |                |
| Filipino (Philippines)                                         | fil-PH         | fil        | missing        |
| Faroese (Faroe Islands)                                        | fo-FO          | fo         | missing        |
| French (Belgium)                                               | fr-BE          |            |                |
| French (Canada)                                                | fr-CA          |            | missing        |
| French (Congo, DRC)                                            | fr-CD          |            | missing        |
| French (Switzerland)                                           | fr-CH          |            |                |
| French (Côte d’Ivoire)                                         | fr-CI          |            | missing        |
| French (Cameroon)                                              | fr-CM          |            | missing        |
| French (France)                                                | fr-FR          | fr         |                |
| French (Haiti)                                                 | fr-HT          |            | missing        |
| French (Luxembourg)                                            | fr-LU          |            |                |
| French (Morocco)                                               | fr-MA          |            | missing        |
| French (Principality of Monaco)                                | fr-MC          |            | missing        |
| French (Mali)                                                  | fr-ML          |            | missing        |
| French (Réunion)                                               | fr-RE          |            | missing        |
| French (Senegal)                                               | fr-SN          |            | missing        |
| Frisian (Netherlands)                                          | fy-NL          | fy         | missing        |
| Irish (Ireland)                                                | ga-IE          | ga         | missing        |
| Scottish Gaelic (United Kingdom)                               | gd-GB          |            | missing        |
| Galician (Spain)                                               | gl-ES          | gl         | missing        |
| Guarani (Paraguay)                                             | gn-PY          | gn         | missing        |
| Alsatian (France)                                              | gsw-FR         | gsw        | missing        |
| Gujarati (India)                                               | gu-IN          | gu         | missing        |
| Hausa (Latin)                                                  | ha-Latn        | ha         | missing        |
| Hausa (Latin, Nigeria)                                         | ha-Latn-NG     |            | missing        |
| Hawaiian (United States)                                       | haw-US         | haw        | missing        |
| Hebrew (Israel)                                                | he-IL          | he         |                |
| Hindi (India)                                                  | hi-IN          | ho         | missing        |
| Croatian (Latin, Bosnia and Herzegovina)                       | hr-BA          |            | missing        |
| Croatian (Croatia)                                             | hr-HR          | hr         |                |
| Upper Sorbian (Germany)                                        | hsb-DE         | hsb        | missing        |
| Hungarian (Hungary)                                            | hu-HU          | hu         |                |
| Armenian (Armenia)                                             | hy-AM          | hy         | missing        |
| Indonesian (Indonesia)                                         | id-ID          | id         |                |
| Igbo (Nigeria)                                                 | ig-NG          | ig         | missing        |
| Yi (People's Republic of China)                                | ii-CN          | ii         | missing        |
| Icelandic (Iceland)                                            | is-IS          | is         | missing        |
| Italian (Switzerland)                                          | it-CH          |            | missing        |
| Italian (Italy)                                                | it-IT          | it         |                |
| Inuktitut (Syllabics)                                          | iu-Cans        |            | missing        |
| Inuktitut (Syllabics, Canada)                                  | iu-Cans-CA     |            | missing        |
| Inuktitut (Latin)                                              | iu-Latn        |            | missing        |
| Inuktitut (Latin, Canada)                                      | iu-Latn-CA     |            | missing        |
| Japanese (Japan)                                               | ja-JP          | ja         |                |
| Georgian (Georgia)                                             | ka-GE          | ka         |                |
| Kazakh (Kazakhstan)                                            | kk-KZ          | kk         | missing        |
| Greenlandic (Greenland)                                        | kl-GL          | kl         | missing        |
| Khmer (Cambodia)                                               | km-KH          | km         | missing        |
| Kannada (India)                                                | kn-IN          | kn         | missing        |
| Konkani (India)                                                | kok-IN         | kok        | missing        |
| Korean (Korea)                                                 | ko-KR          | ko         |                |
| Kashmiri (Perso-Arabic)                                        | ks-Arab        | ks         | missing        |
| Central Kurdish                                                | ku-Arab        | ku         | missing        |
| Central Kurdish (Iraq)                                         | ku-Arab-IQ     |            | missing        |
| Kyrgyz (Kyrgyzstan)                                            | ky-KG          | ky         | missing        |
| Luxembourgish (Luxembourg)                                     | lb-LU          | lb         |                |
| Lao (Lao P.D.R.)                                               | lo-LA          | lo         | missing        |
| Lithuanian (Lithuania)                                         | lt-LT          | lt         | missing        |
| Latvian (Latvia)                                               | lv-LV          | lv         | missing        |
| Maori (New Zealand)                                            | mi-NZ          | mi         | missing        |
| Macedonian (Macedonia (Former Yugoslav Republic of Macedonia)) | mk-MK          | mk         | missing        |
| Malayalam (India)                                              | ml-IN          | ml         | missing        |
| Mongolian (Cyrillic)                                           | mn-Cyrl        | mn         | missing        |
| Mongolian (Cyrillic, Mongolia)                                 | mn-MN          |            | missing        |
| Mongolian (Traditional Mongolian)                              | mn-Mong        |            | missing        |
| Mongolian (Traditional Mongolian, People's Republic of China)  | mn-Mong-CN     |            | missing        |
| Mongolian (Traditional Mongolian, Mongolia)                    | mn-Mong-MN     |            | missing        |
| Mohawk (Canada)                                                | moh-CA         | moh        | missing        |
| Marathi (India)                                                | mr-IN          | mr         | missing        |
| Malay (Brunei Darussalam)                                      | ms-BN          |            | missing        |
| Malay (Malaysia)                                               | ms-MY          | ms         |                |
| Maltese (Malta)                                                | mt-MT          | mt         | missing        |
| Burmese (Myanmar)                                              | my-MM          | my         | missing        |
| Norwegian, Bokmål (Norway)                                     | nb-NO          | nb         |                |
| Nepali (India)                                                 | ne-IN          |            | missing        |
| Nepali (Nepal)                                                 | ne-NP          | ne         | missing        |
| Dutch (Belgium)                                                | nl-BE          |            |                |
| Dutch (Netherlands)                                            | nl-NL          | nl         |                |
| Norwegian, Nynorsk (Norway)                                    | nn-NO          | nn         | missing        |
| Sesotho sa Leboa (South Africa)                                | nso-ZA         | nso        | missing        |
| Occitan (France)                                               | oc-FR          | oc         | missing        |
| Oromo (Ethiopia)                                               | om-ET          | om         | missing        |
| Odia (India)                                                   | or-IN          | or         | missing        |
| Punjabi                                                        | pa-Arab        |            | missing        |
| Punjabi (Islamic Republic of Pakistan)                         | pa-Arab-PK     |            | missing        |
| Punjabi (India)                                                | pa-IN          | pa         | missing        |
| Polish (Poland)                                                | pl-PL          | pl         |                |
| Dari (Afghanistan)                                             | prs-AF         | prs        | missing        |
| Pashto (Afghanistan)                                           | ps-AF          | ps         | missing        |
| Portuguese (Brazil)                                            | pt-BR          |            |                |
| Portuguese (Portugal)                                          | pt-PT          | pt         |                |
| K'iche (Latin, Guatemala)                                      | quc-Latn-GT    | quc        | missing        |
| K'iche (Guatemala)                                             | qut-GT         | qut        | missing        |
| Quechua (Bolivia)                                              | quz-BO         |            | missing        |
| Quechua (Ecuador)                                              | quz-EC         |            | missing        |
| Quechua (Peru)                                                 | quz-PE         | quz        | missing        |
| Romansh (Switzerland)                                          | rm-CH          | rm         | missing        |
| Romanian (Moldova)                                             | ro-MD          |            | missing        |
| Romanian (Romania)                                             | ro-RO          | ro         |                |
| Russian (Moldova)                                              | ru-MD          |            | missing        |
| Russian (Russia)                                               | ru-RU          | ru         |                |
| Kinyarwanda (Rwanda)                                           | rw-RW          | rw         | missing        |
| Sakha (Russia)                                                 | sah-RU         | sah        | missing        |
| Sanskrit (India)                                               | sa-IN          | sah        | missing        |
| Sindhi                                                         | sd-Arab        | sd         | missing        |
| Sindhi (Islamic Republic of Pakistan)                          | sd-Arab-PK     |            | missing        |
| Sami, Northern (Finland)                                       | se-FI          | se         | missing        |
| Sami, Northern (Norway)                                        | se-NO          |            | missing        |
| Sami, Northern (Sweden)                                        | se-SE          |            | missing        |
| Sinhala (Sri Lanka)                                            | si-LK          | si         | missing        |
| Slovak (Slovakia)                                              | sk-SK          | sk         |                |
| Slovenian (Slovenia)                                           | sl-SI          | sl         | missing        |
| Sami, Southern (Norway)                                        | sma-NO         | sma        | missing        |
| Sami, Southern (Sweden)                                        | sma-SE         |            | missing        |
| Sami, Lule (Norway)                                            | smj-NO         | smj        | missing        |
| Sami, Lule (Sweden)                                            | smj-SE         |            | missing        |
| Sami, Inari (Finland)                                          | smn-FI         | smn        | missing        |
| Sami, Skolt (Finland)                                          | sms-FI         | sms        | missing        |
| Somali (Somalia)                                               | so-SO          | so         | missing        |
| Albanian (Albania)                                             | sq-AL          | sq         | missing        |
| Serbian (Cyrillic)                                             | sr-Cyrl        | sr         |                |
| Serbian (Cyrillic, Bosnia and Herzegovina)                     | sr-Cyrl-BA     |            | missing        |
| Serbian (Cyrillic, Serbia and Montenegro (Former))             | sr-Cyrl-CS     |            | missing        |
| Serbian (Cyrillic, Montenegro)                                 | sr-Cyrl-ME     |            | missing        |
| Serbian (Cyrillic, Serbia)                                     | sr-Cyrl-RS     |            | missing        |
| Serbian (Latin)                                                | sr-Latn        |            |                |
| Serbian (Latin, Bosnia and Herzegovina)                        | sr-Latn-BA     |            | missing        |
| Serbian (Latin, Serbia and Montenegro (Former))                | sr-Latn-CS     |            | missing        |
| Serbian (Latin, Montenegro)                                    | sr-Latn-ME     |            | missing        |
| Serbian (Latin, Serbia)                                        | sr-Latn-RS     |            | missing        |
| Sotho (South Africa)                                           | st-ZA          | st         | missing        |
| Swedish (Finland)                                              | sv-FI          |            | missing        |
| Swedish (Sweden)                                               | sv-SE          | sv         |                |
| Kiswahili (Kenya)                                              | sw-KE          |            | missing        |
| Syriac (Syria)                                                 | syr-SY         |            | missing        |
| Tamil (India)                                                  | ta-IN          |            | missing        |
| Tamil (Sri Lanka)                                              | ta-LK          | ta         | missing        |
| Telugu (India)                                                 | te-IN          | te         | missing        |
| Tajik (Cyrillic)                                               | tg-Cyrl        | tg         | missing        |
| Tajik (Cyrillic, Tajikistan)                                   | tg-Cyrl-TJ     |            | missing        |
| Thai (Thailand)                                                | th-TH          | th         |                |
| Tigrinya (Eritrea)                                             | ti-ER          | ti         | missing        |
| Tigrinya (Ethiopia)                                            | ti-ET          |            | missing        |
| Turkmen (Turkmenistan)                                         | tk-TM          | tk         | missing        |
| Setswana (Botswana)                                            | tn-BW          | tn         | missing        |
| Setswana (South Africa)                                        | tn-ZA          |            | missing        |
| Turkish (Turkey)                                               | tr-TR          | tr         |                |
| Tsonga (South Africa)                                          | ts-ZA          | ts         | missing        |
| Tatar (Russia)                                                 | tt-RU          | tt         | missing        |
| Tamazight (Latin)                                              | tzm-Latn       | tzm        | missing        |
| Tamazight (Latin, Algeria)                                     | tzm-Latn-DZ    |            | missing        |
| Uyghur (People's Republic of China)                            | ug-CN          | ug         | missing        |
| Ukrainian (Ukraine)                                            | uk-UA          | uk         |                |
| Urdu (India)                                                   | ur-IN          |            | missing        |
| Urdu (Islamic Republic of Pakistan)                            | ur-PK          | ur         |                |
| Uzbek (Cyrillic)                                               | uz-Cyrl        |            | missing        |
| Uzbek (Cyrillic, Uzbekistan)                                   | uz-Cyrl-UZ     |            | missing        |
| Uzbek (Latin)                                                  | uz-Latn        |            | missing        |
| Uzbek (Latin, Uzbekistan)                                      | uz-Latn-UZ     | uz         |                |
| Venda (South Africa)                                           | ve-ZA          | ve         | missing        |
| Vietnamese (Vietnam)                                           | vi-VN          | vi         |                |
| Wolof (Senegal)                                                | wo-SN          | wo         | missing        |
| Xhosa (South Africa)                                           | xh-ZA          | xh         | missing        |
| Yoruba (Nigeria)                                               | yo-NG          | yo         | missing        |
| Chinese (Simplified) (zh-CHS)                                  | zh-CHS         |            | missing        |
| Chinese (Traditional) (zh-CHT)                                 | zh-CHT         |            | missing        |
| Chinese (Simplified, People's Republic of China)               | zh-CN          | zh         |                |
| Chinese (Simplified) (zh-Hans)                                 | zh-Hans        |            | missing        |
| Chinese (Traditional) (zh-Hant)                                | zh-Hant        |            | missing        |
| Chinese (Traditional, Hong Kong S.A.R.)                        | zh-HK          |            | missing        |
| Chinese (Traditional, Macao S.A.R.)                            | zh-MO          |            | missing        |
| Chinese (Simplified, Singapore)                                | zh-SG          |            | missing        |
| Chinese (Traditional, Taiwan)                                  | zh-TW          |            |                |
| Zulu (South Africa)                                            | zu-ZA          |            | missing        |